@@ -12,18 +12,18 @@ from appium.webdriver.common.appiumby import AppiumBy
 import os
 import time
 
-class PassTest(ItineraryTestCase):
+class PassImportTest(ItineraryTestCase):
     def setUp(self):
         # open the passes & programs page
-        self.driver.find_element(by=AppiumBy.NAME, value="Passes & Programs").click()
+        self.driver.find_element(by=AppiumBy.NAME, value="My Data").click()
+        self.driver.find_element(by=AppiumBy.NAME, value="Manage your Passes").click()
 
     def test_programMembership(self):
-        self.assertTrue(self.driver.find_element(by=AppiumBy.NAME, value="Import…").is_displayed())
-        self.assertTrue(self.driver.find_element(by=AppiumBy.NAME, value="Import…").is_enabled())
-        self.driver.find_element(by=AppiumBy.NAME, value="Import…").click()
+        self.assertTrue(self.driver.find_element(by=AppiumBy.NAME, value="Import From File").is_displayed())
+        self.assertTrue(self.driver.find_element(by=AppiumBy.NAME, value="Import From File").is_enabled())
+        self.driver.find_element(by=AppiumBy.NAME, value="Import From File").click()
         self.openFile("data/bahncard.json")
         self.driver.find_element(by=AppiumBy.NAME, value="Import selection").click()
-        self.assertFalse(self.driver.find_element(by=AppiumBy.NAME, value="Import…").is_displayed())
         self.driver.find_element(by=AppiumBy.NAME, value="BahnCard 25 (2. Kl.) (BC25)").click()
         self.driver.find_element(by=AppiumBy.NAME, value="Edit").click()
 
@@ -49,8 +49,14 @@ class PassTest(ItineraryTestCase):
         # TODO how to check this element does not exist anymore?
         # self.assertFalse(self.driver.find_element(by=AppiumBy.NAME, value="BahnCard 25 (2. Kl.) (BC25)").is_displayed())
 
+class PassManualTest(ItineraryTestCase):
+    def setUp(self):
+        # open the passes & programs page
+        self.driver.find_element(by=AppiumBy.NAME, value="My Data").click()
+        self.driver.find_element(by=AppiumBy.NAME, value="Manage your Passes").click()
+
     def test_addProgramMembership(self):
-        self.driver.find_element(by=AppiumBy.NAME, value="Add Program Membership…").click()
+        self.driver.find_element(by=AppiumBy.NAME, value="Add Manually").click()
         saveButton = self.driver.find_element(by=AppiumBy.NAME, value="Save")
         self.assertFalse(saveButton.is_enabled())
 
