@@ -18,7 +18,7 @@ public:
     ~DocumentManager() override;
 
     /** Lists all documents in storage. */
-    QVector<QString> documents() const;
+    QList<QString> documents() const;
     /** Returns @c true if a document with the given id is present. */
     bool hasDocument(const QString &id) const;
 
