@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2018 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2025 Carl Schwan <carl@carlschwan.eu>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -36,8 +37,10 @@
 #include "pkpassimageprovider.h"
 #include "pkpassmanager.h"
 #include "publictransport.h"
+#include "qmlsingletons.h"
 #include "reservationhelper.h"
 #include "reservationmanager.h"
+#include "reservationonlinepostprocessor.h"
 #include "settings.h"
 #include "statisticsmodel.h"
 #include "statisticstimerangemodel.h"
@@ -59,13 +62,6 @@
 #include "util.h"
 #include "weatherforecastmodel.h"
 
-#if HAVE_MATRIX
-#include "matrix/matrixbeacon.h"
-#include "matrix/matrixroomsmodel.h"
-
-#include <Quotient/keyverificationsession.h>
-#endif
-
 #include "weatherforecastmanager.h"
 
 #include <KItinerary/CountryDb>
@@ -115,23 +111,6 @@
 
 using namespace Qt::Literals::StringLiterals;
 
-#if !HAVE_MATRIX
-class MatrixBeaconStub : public QObject
-{
-    Q_OBJECT
-    Q_PROPERTY(QVariant connection MEMBER m_connection)
-    QVariant m_connection;
-};
-#endif
-
-void registerKPkPassTypes()
-{
-    qmlRegisterUncreatableMetaObject(KPkPass::Barcode::staticMetaObject, "org.kde.pkpass", 1, 0, "Barcode", {});
-    qmlRegisterUncreatableMetaObject(KPkPass::Field::staticMetaObject, "org.kde.pkpass", 1, 0, "Field", {});
-    qmlRegisterUncreatableType<KPkPass::Pass>("org.kde.pkpass", 1, 0, "Pass", {});
-    qmlRegisterUncreatableType<KPkPass::BoardingPass>("org.kde.pkpass", 1, 0, "BoardingPass", {});
-}
-
 void registerKItineraryTypes()
 {
     qRegisterMetaType<KItinerary::KnowledgeDb::DrivingSide>();
@@ -142,76 +121,6 @@ void registerKItineraryTypes()
     });
 }
 
-void registerQuotientTypes()
-{
-#if HAVE_MATRIX
-    qmlRegisterUncreatableType<Quotient::KeyVerificationSession>("org.kde.quotient", 1, 0, "KeyVerificationSession", {});
-#endif
-}
-
-void registerApplicationTypes()
-{
-    qRegisterMetaType<ReservationManager *>();
-    qRegisterMetaType<Transfer::Alignment>();
-    qRegisterMetaType<TripGroupManager *>();
-    qRegisterMetaType<WeatherForecast>();
-    qRegisterMetaType<Permission::Permission>();
-    qmlRegisterUncreatableMetaObject(HealthCertificateManager::staticMetaObject, "org.kde.itinerary", 1, 0, "HealthCertificateManager", {});
-
-    qmlRegisterUncreatableMetaObject(LocationInformation::staticMetaObject, "org.kde.itinerary", 1, 0, "LocationInformation", {});
-    qmlRegisterUncreatableMetaObject(StatisticsItem::staticMetaObject, "org.kde.itinerary", 1, 0, "StatisticsItem", {});
-    qmlRegisterUncreatableMetaObject(TimelineElement::staticMetaObject, "org.kde.itinerary", 1, 0, "TimelineElement", {});
-    qmlRegisterUncreatableMetaObject(Transfer::staticMetaObject, "org.kde.itinerary", 1, 0, "Transfer", {});
-
-    qmlRegisterUncreatableMetaObject(Permission::staticMetaObject, "org.kde.itinerary", 1, 0, "Permission", {});
-#if HAVE_MATRIX
-    qmlRegisterUncreatableMetaObject(MatrixRoomsModel::staticMetaObject, "org.kde.itinerary", 1, 0, "MatrixRoomsModel", {});
-#endif
-
-    qmlRegisterType<CountrySubdivisionModel>("org.kde.itinerary", 1, 0, "CountrySubdivisionModel");
-    qmlRegisterType<DocumentsModel>("org.kde.itinerary", 1, 0, "DocumentsModel");
-    qmlRegisterType<JourneySectionModel>("org.kde.itinerary", 1, 0, "JourneySectionModel");
-    qmlRegisterType<KDEConnectDeviceModel>("org.kde.itinerary", 1, 0, "KDEConnectDeviceModel");
-    qmlRegisterType<StatisticsModel>("org.kde.itinerary", 1, 0, "StatisticsModel");
-    qmlRegisterType<StatisticsTimeRangeModel>("org.kde.itinerary", 1, 0, "StatisticsTimeRangeModel");
-    qmlRegisterType<TicketTokenModel>("org.kde.itinerary", 1, 0, "TicketTokenModel");
-    qmlRegisterType<TimelineDelegateController>("org.kde.itinerary", 1, 0, "TimelineDelegateController");
-    qmlRegisterType<TimelineModel>("org.kde.itinerary", 1, 0, "TimelineModel");
-    qmlRegisterType<TimelineSectionDelegateController>("org.kde.itinerary", 1, 0, "TimelineSectionDelegateController");
-    qmlRegisterType<TransferDelegateController>("org.kde.itinerary", 1, 0, "TransferDelegateController");
-    qmlRegisterType<TripGroupController>("org.kde.itinerary", 1, 0, "TripGroupController");
-    qmlRegisterType<TripGroupFilterProxyModel>("org.kde.itinerary", 1, 0, "TripGroupFilterProxyModel");
-    qmlRegisterType<TripGroupLocationModel>("org.kde.itinerary", 1, 0, "TripGroupLocationModel");
-    qmlRegisterType<TripGroupMapModel>("org.kde.itinerary", 1, 0, "TripGroupMapModel");
-    qmlRegisterType<TripGroupSplitModel>("org.kde.itinerary", 1, 0, "TripGroupSplitModel");
-    qmlRegisterType<WeatherForecastModel>("org.kde.itinerary", 1, 0, "WeatherForecastModel");
-#if HAVE_MATRIX
-    qmlRegisterType<MatrixBeacon>("org.kde.itinerary", 1, 0, "MatrixBeacon");
-#else
-    qmlRegisterType<MatrixBeaconStub>("org.kde.itinerary", 1, 0, "MatrixBeacon");
-#endif
-    qmlRegisterType<OnlineTicketImporter>("org.kde.itinerary", 1, 0, "OnlineTicketImporter");
-}
-
-// for registering QML singletons only
-static ReservationManager *s_reservationManager = nullptr;
-static DocumentManager *s_documentManager = nullptr;
-static FavoriteLocationModel *s_favoriteLocationModel = nullptr;
-static PkPassManager *s_pkPassManager = nullptr;
-static Settings *s_settings = nullptr;
-static TransferManager *s_tranferManager = nullptr;
-static TripGroupManager *s_tripGroupManager = nullptr;
-static LiveDataManager *s_liveDataMnager = nullptr;
-static WeatherForecastManager *s_weatherForecastManager = nullptr;
-static MapDownloadManager *s_mapDownloadManager = nullptr;
-static PassManager *s_passManager = nullptr;
-static MatrixController *s_matrixController = nullptr;
-static ImportController *s_importController = nullptr;
-static TripGroupModel *s_tripGroupModel = nullptr;
-static TraewellingController *s_traewellingController = nullptr;
-
-#define REGISTER_SINGLETON_INSTANCE(Class, Instance) qmlRegisterSingletonInstance<Class>("org.kde.itinerary", 1, 0, #Class, Instance);
-
 #define REGISTER_SINGLETON_GADGET_FACTORY(Class)                                                                                                               \
     qmlRegisterSingletonType("org.kde.itinerary", 1, 0, #Class, [](QQmlEngine *, QJSEngine *engine) -> QJSValue {                                              \
         return engine->toScriptValue(Class());                                                                                                                 \
@@ -219,23 +128,6 @@ static TraewellingController *s_traewellingController = nullptr;
 
 void registerApplicationSingletons()
 {
-    REGISTER_SINGLETON_INSTANCE(ApplicationController, ApplicationController::instance())
-    REGISTER_SINGLETON_INSTANCE(ReservationManager, s_reservationManager)
-    REGISTER_SINGLETON_INSTANCE(DocumentManager, s_documentManager)
-    REGISTER_SINGLETON_INSTANCE(FavoriteLocationModel, s_favoriteLocationModel)
-    REGISTER_SINGLETON_INSTANCE(PkPassManager, s_pkPassManager)
-    REGISTER_SINGLETON_INSTANCE(Settings, s_settings)
-    REGISTER_SINGLETON_INSTANCE(TransferManager, s_tranferManager)
-    REGISTER_SINGLETON_INSTANCE(TripGroupManager, s_tripGroupManager)
-    REGISTER_SINGLETON_INSTANCE(LiveDataManager, s_liveDataMnager)
-    REGISTER_SINGLETON_INSTANCE(WeatherForecastManager, s_weatherForecastManager)
-    REGISTER_SINGLETON_INSTANCE(MapDownloadManager, s_mapDownloadManager)
-    REGISTER_SINGLETON_INSTANCE(PassManager, s_passManager)
-    REGISTER_SINGLETON_INSTANCE(MatrixController, s_matrixController);
-    REGISTER_SINGLETON_INSTANCE(ImportController, s_importController);
-    REGISTER_SINGLETON_INSTANCE(TripGroupModel, s_tripGroupModel);
-    REGISTER_SINGLETON_INSTANCE(TraewellingController, s_traewellingController);
-
     REGISTER_SINGLETON_GADGET_FACTORY(DevelopmentModeController)
     REGISTER_SINGLETON_GADGET_FACTORY(Factory)
     REGISTER_SINGLETON_GADGET_FACTORY(Localizer)
@@ -246,13 +138,8 @@ void registerApplicationSingletons()
     REGISTER_SINGLETON_GADGET_FACTORY(ReservationHelper)
     REGISTER_SINGLETON_GADGET_FACTORY(UnitConversion)
     REGISTER_SINGLETON_GADGET_FACTORY(Util)
-
-    qmlRegisterSingletonType<Clipboard>("org.kde.itinerary", 1, 0, "Clipboard", [](QQmlEngine *, QJSEngine *) -> QObject * {
-        return new Clipboard;
-    });
 }
 
-#undef REGISTER_SINGLETON_INSTANCE
 #undef REGISTER_SINGLETON_GADGET_FACTORY
 
 static QNetworkAccessManager *namFactory()
@@ -329,6 +216,28 @@ int main(int argc, char **argv)
     aboutData.setShortDescription(i18n("Digital Travel Assistant"));
     aboutData.setCopyrightStatement(i18n("Copyright © The KDE Community"));
     aboutData.setDesktopFileName(QStringLiteral("org.kde.itinerary"));
+
+    aboutData.addComponent(i18nc("@info:credit", "Wikidata"), i18nc("@info:credit", "Provides various metadata like train station names, driving side, and power plug types."), {}, u"https://www.wikidata.org/"_s, KAboutLicense::CC0_V1);
+    aboutData.addComponent(i18nc("@info:credit", "OpenStreetMap"), i18nc("@info:credit", "Provides both indoor and outdoor maps. ©OpenStreetMap contributors"), {}, u"https://www.openstreetmap.org/"_s, KAboutLicense::ODbL_V1);
+    aboutData.addComponent(i18nc("@info:credit", "OpenSSL"), i18nc("@info:credit", "Secure network interaction with TLS. © 1998-2018 The OpenSSL Project"), {}, u"https://www.openssl.org/"_s, KAboutLicense::Apache_V2);
+    aboutData.addComponent(i18nc("@info:credit", "ZXing"), i18nc("@info:credit", "QR-Code scanning. © 2016 ZXing Authors, © 2016 Nu-book Inc."), {}, u"https://github.com/nu-book/zxing-cpp"_s, KAboutLicense::Apache_V2);
+    aboutData.addComponent(i18nc("@info:credit", "Poppler"), i18nc("@info:credit", "PDF parsing"), {}, u"https://poppler.freedesktop.org/"_s, KAboutLicense::GPL_V2);
+
+#ifdef Q_OS_ANDROID
+    aboutData.addComponent(i18nc("@info:credit", "FreeType"), i18nc("@info:credit", "Copyright (C) 2006-2020 by David Turner, Robert Wilhelm, and Werner Lemberg."), {}, u"https://www.freetype.org/"_s, KAboutLicense::FTL);
+    aboutData.addComponent(i18nc("@info:credit", "libintl lite"), i18nc("@info:credit", "Internalisation"), {}, u"https://github.com/j-jorge/libintl-lite"_s, KAboutLicense::BSL_V1);
+#endif
+
+    aboutData.addComponent(i18nc("@info:credit", "libqrencode"), i18nc("@info:credit", "QR-Code Generation. © 2006-2018 Kentaro Fukuchi"), {}, u"https://github.com/fukuchi/libqrencode"_s, KAboutLicense::LGPL_V2_1);
+    aboutData.addComponent(i18nc("@info:credit", "libical"), i18nc("@info:credit", "© The libical developers"), {}, u"https://github.com/libical/libical"_s, KAboutLicense::LGPL_V2_1);
+    aboutData.addComponent(i18nc("@info:credit", "libxml2"), i18nc("@info:credit", "Copyright (C) 1998-2012 Daniel Veillard"), {}, u"https://gitlab.gnome.org/GNOME/libxml2/-/wikis/home"_s, KAboutLicense::MIT);
+
+#if HAVE_MATRIX
+    aboutData.addComponent(i18nc("@info:credit", "libQuotient"), i18nc("@info:credit", "Matrix integration."), {}, u"https://github.com/quotient-im/libquotient"_s, KAboutLicense::LGPL_V2_1);
+    aboutData.addComponent(i18nc("@info:credit", "QtKeychain"), i18nc("@info:credit", "Secure password storage."), {}, u"https://github.com/frankosterfeld/qtkeychain/"_s, KAboutLicense::BSD_3_Clause);
+    aboutData.addComponent(i18nc("@info:credit", "Olm"), i18nc("@info:credit", "Matrix crypto library."), {}, u"https://gitlab.matrix.org/matrix-org/olm"_s, KAboutLicense::Apache_V2);
+#endif
+
     KAboutData::setApplicationData(aboutData);
 
     QCommandLineParser parser;
@@ -355,38 +264,40 @@ int main(int argc, char **argv)
     IntentHandler intentHandler;
 
     Settings settings;
-    s_settings = &settings;
+    SettingsInstance::instance = &settings;
 
     PkPassManager pkPassMgr;
     pkPassMgr.setNetworkAccessManagerFactory(namFactory);
-    s_pkPassManager = &pkPassMgr;
+    PkPassManagerInstance::instance = &pkPassMgr;
 
     ReservationManager resMgr;
-    s_reservationManager = &resMgr;
+    ReservationManagerInstance::instance = &resMgr;
 
     DocumentManager docMgr;
-    s_documentManager = &docMgr;
+    DocumentManagerInstance::instance = &docMgr;
 
     FavoriteLocationModel favLocModel;
-    s_favoriteLocationModel = &favLocModel;
+    FavoriteLocationModelInstance::instance = &favLocModel;
 
     TripGroupManager tripGroupMgr;
     tripGroupMgr.setReservationManager(&resMgr);
-    s_tripGroupManager = &tripGroupMgr;
+    TripGroupManagerInstance::instance = &tripGroupMgr;
 
     LiveDataManager liveDataMgr;
     liveDataMgr.setPkPassManager(&pkPassMgr);
     liveDataMgr.setReservationManager(&resMgr);
     liveDataMgr.setPollingEnabled(settings.queryLiveData());
     liveDataMgr.setShowNotificationsOnLockScreen(settings.showNotificationOnLockScreen());
+    liveDataMgr.setDownloadAssetsEnabled(settings.wikimediaOnlineContentEnabled());
     QObject::connect(&settings, &Settings::queryLiveDataChanged, &liveDataMgr, &LiveDataManager::setPollingEnabled);
     QObject::connect(&settings, &Settings::showNotificationOnLockScreenChanged, &liveDataMgr, &LiveDataManager::setShowNotificationsOnLockScreen);
-    s_liveDataMnager = &liveDataMgr;
+    QObject::connect(&settings, &Settings::wikimediaOnlineContentEnabledChanged, &liveDataMgr, &LiveDataManager::setDownloadAssetsEnabled);
+    LiveDataManagerInstance::instance = &liveDataMgr;
 
-    WeatherForecastManager weatherForecastMgr;
-    weatherForecastMgr.setAllowNetworkAccess(settings.weatherForecastEnabled());
-    QObject::connect(&settings, &Settings::weatherForecastEnabledChanged, &weatherForecastMgr, &WeatherForecastManager::setAllowNetworkAccess);
-    s_weatherForecastManager = &weatherForecastMgr;
+    ReservationOnlinePostprocessor resOnlinePostproc(&resMgr, &settings, namFactory);
+
+    WeatherForecastManager::setAllowNetworkAccess(settings.weatherForecastEnabled());
+    QObject::connect(&settings, &Settings::weatherForecastEnabledChanged, &WeatherForecastManager::setAllowNetworkAccess);
 
     TransferManager transferManager;
     transferManager.setReservationManager(&resMgr);
@@ -394,37 +305,36 @@ int main(int argc, char **argv)
     transferManager.setLiveDataManager(&liveDataMgr);
     transferManager.setAutoAddTransfers(settings.autoAddTransfers());
     transferManager.setAutoFillTransfers(settings.autoFillTransfers());
+    transferManager.setDownloadAssetsEnabled(settings.wikimediaOnlineContentEnabled());
     QObject::connect(&settings, &Settings::autoAddTransfersChanged, &transferManager, &TransferManager::setAutoAddTransfers);
     QObject::connect(&settings, &Settings::autoFillTransfersChanged, &transferManager, &TransferManager::setAutoFillTransfers);
-    s_tranferManager = &transferManager;
+    QObject::connect(&settings, &Settings::wikimediaOnlineContentEnabledChanged, &transferManager, &TransferManager::setDownloadAssetsEnabled);
+    TransferManagerInstance::instance = &transferManager;
 
     tripGroupMgr.setTransferManager(&transferManager);
 
     TripGroupModel tripGroupModel;
     tripGroupModel.setTripGroupManager(&tripGroupMgr);
-    s_tripGroupModel = &tripGroupModel;
+    TripGroupModelInstance::instance = &tripGroupModel;
 
     MapDownloadManager mapDownloadMgr;
     mapDownloadMgr.setReservationManager(&resMgr);
-    mapDownloadMgr.setAutomaticDownloadEnabled(s_settings->preloadMapData());
-    QObject::connect(s_settings, &Settings::preloadMapDataChanged, &mapDownloadMgr, &MapDownloadManager::setAutomaticDownloadEnabled);
-    s_mapDownloadManager = &mapDownloadMgr;
+    mapDownloadMgr.setAutomaticDownloadEnabled(settings.preloadMapData());
+    QObject::connect(&settings, &Settings::preloadMapDataChanged, &mapDownloadMgr, &MapDownloadManager::setAutomaticDownloadEnabled);
+    MapDownloadManagerInstance::instance = &mapDownloadMgr;
 
     KItinerary::JsonLdDocument::registerType<GenericPkPass>();
     PassManager passMgr;
-    s_passManager = &passMgr;
-
-    MatrixController matrixController;
-    s_matrixController = &matrixController;
+    PassManagerInstance::instance = &passMgr;
 
     ImportController importController;
     importController.setNetworkAccessManagerFactory(namFactory);
     importController.setReservationManager(&resMgr);
     QObject::connect(&intentHandler, &IntentHandler::handleIntent, &importController, &ImportController::importFromIntent);
-    s_importController = &importController;
+    ImportControllerInstance::instance = &importController;
 
     TraewellingController traewellingController(namFactory);
-    s_traewellingController = &traewellingController;
+    TraewellingControllerInstance::instance = &traewellingController;
 
     ApplicationController appController;
     appController.setNetworkAccessManagerFactory(namFactory);
@@ -458,10 +368,10 @@ int main(int argc, char **argv)
 
     OnlineTicketImporter::setNetworkAccessManagerFactory(namFactory);
 
-    registerKPkPassTypes();
+    MatrixController matrixController;
+    MatrixControllerInstance::instance = &matrixController;
+
     registerKItineraryTypes();
-    registerQuotientTypes();
-    registerApplicationTypes();
     registerApplicationSingletons();
 
     QQmlApplicationEngine engine;
@@ -480,7 +390,7 @@ int main(int argc, char **argv)
         }
         return nullptr;
     });
-    engine.addImageProvider(QStringLiteral("org.kde.pkpass"), pkPassImageProvider);
+    engine.addImageProvider(u"org.kde.pkpass"_s, pkPassImageProvider);
 
     KLocalization::setupLocalizedContext(&engine);
     engine.loadFromModule("org.kde.itinerary", "Main");
@@ -503,5 +413,3 @@ int main(int argc, char **argv)
 
     return app.exec();
 }
-
-#include "main.moc"
