@@ -4,31 +4,30 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include "logging.h"
 #include "mapdownloadmanager.h"
 #include "reservationmanager.h"
 
-#include "solidextras/networkstatus.h"
-
 #include <KOSMIndoorMap/MapLoader>
 
 #include <KItinerary/LocationUtil>
 #include <KItinerary/Place>
 #include <KItinerary/SortUtil>
 
-#include <QDebug>
+#include <QNetworkInformation>
 #include <QTimer>
 
 #include <cmath>
 
 using namespace KItinerary;
-using SolidExtras::NetworkStatus;
 
 MapDownloadManager::MapDownloadManager(QObject *parent)
     : QObject(parent)
-    , m_netStatus(new NetworkStatus(this))
 {
-    connect(m_netStatus, &NetworkStatus::connectivityChanged, this, &MapDownloadManager::networkStatusChanged);
-    connect(m_netStatus, &NetworkStatus::meteredChanged, this, &MapDownloadManager::networkStatusChanged);
+    QNetworkInformation::loadDefaultBackend();
+    auto netInfo = QNetworkInformation::instance();
+    connect(netInfo, &QNetworkInformation::reachabilityChanged, this, &MapDownloadManager::networkStatusChanged);
+    connect(netInfo, &QNetworkInformation::isMeteredChanged, this, &MapDownloadManager::networkStatusChanged);
 }
 
 MapDownloadManager::~MapDownloadManager() = default;
@@ -62,13 +61,26 @@ void MapDownloadManager::download()
         addRequestForBatch(batchId);
     }
 
-    qDebug() << m_pendingRequests.size() << "pending download requests" << m_netStatus->connectivity() << m_netStatus->metered();
+    const auto netInfo = QNetworkInformation::instance();
+    qCDebug(Log) << m_pendingRequests.size() << "pending download requests" << netInfo->reachability() << netInfo->isMetered();
+    downloadNext();
+}
+
+void MapDownloadManager::download(const QStringList &batchIds)
+{
+    for (const auto &batchId : batchIds) {
+        addRequestForBatch(batchId, true);
+    }
+
+    const auto netInfo = QNetworkInformation::instance();
+    qCDebug(Log) << m_pendingRequests.size() << "pending download requests" << netInfo->reachability() << netInfo->isMetered();
     downloadNext();
 }
 
 bool MapDownloadManager::canAutoDownload() const
 {
-    return m_autoDownloadEnabled && m_netStatus->connectivity() != NetworkStatus::No && m_netStatus->metered() == NetworkStatus::No;
+    const auto netInfo = QNetworkInformation::instance();
+    return m_autoDownloadEnabled && (netInfo->reachability() == QNetworkInformation::Reachability::Online || netInfo->reachability() == QNetworkInformation::Reachability::Unknown) && !netInfo->isMetered();
 }
 
 void MapDownloadManager::addAutomaticRequestForBatch(const QString &batchId)
@@ -79,14 +91,14 @@ void MapDownloadManager::addAutomaticRequestForBatch(const QString &batchId)
     }
 }
 
-void MapDownloadManager::addRequestForBatch(const QString &batchId)
+void MapDownloadManager::addRequestForBatch(const QString &batchId, bool force)
 {
     const auto res = m_resMgr->reservation(batchId);
     if (!LocationUtil::isLocationChange(res)) {
         return;
     }
     const auto arrTime = SortUtil::endDateTime(res);
-    if (isRelevantTime(arrTime)) {
+    if (force || isRelevantTime(arrTime)) {
         const auto arr = LocationUtil::arrivalLocation(res);
         const auto arrGeo = LocationUtil::geo(arr);
         qDebug() << LocationUtil::name(arr) << arrGeo.latitude() << arrGeo.longitude();
@@ -94,7 +106,7 @@ void MapDownloadManager::addRequestForBatch(const QString &batchId)
     }
 
     const auto depTime = SortUtil::startDateTime(res);
-    if (isRelevantTime(depTime)) {
+    if (force || isRelevantTime(depTime)) {
         const auto dep = LocationUtil::departureLocation(res);
         const auto depGeo = LocationUtil::geo(dep);
         qDebug() << LocationUtil::name(dep) << depGeo.latitude() << depGeo.longitude();
