@@ -13,14 +13,25 @@
 #include "kandroidextras/settings.h"
 #endif
 
+#include <QCoreApplication>
 #include <QDebug>
+#include <QProcess>
+
+using namespace Qt::Literals;
 
 bool NotificationConfigController::canConfigureNotification() const
 {
 #ifdef Q_OS_ANDROID
     return true;
 #else
-    return false; // TODO
+    static bool s_hasNotificationKCM = []{
+        QProcess proc;
+        proc.start(u"kcmshell6"_s, {u"--list"_s});
+        proc.waitForFinished();
+        return proc.readAllStandardOutput().contains("\nkcm_notifications "_L1);
+    }();
+
+    return s_hasNotificationKCM;
 #endif
 }
 
@@ -43,7 +54,10 @@ void NotificationConfigController::configureNotifications()
     intent.putExtra<java::lang::String>(Settings::EXTRA_APP_PACKAGE, Context::getPackageName());
     Activity::startActivity(intent, 0);
 #else
-    // TODO
+    QProcess proc;
+    proc.setProgram(u"kcmshell6"_s);
+    proc.setArguments({u"--args"_s, "--notifyrc %1"_L1.arg(QCoreApplication::applicationName()), u"notifications"_s});
+    proc.startDetached();
 #endif
 }
 
