@@ -38,10 +38,8 @@ class PublicTransport
 public:
     /** Obtain a KPublicTransport location object from a KItinerary place.
      *  @param place The place to convert to a location
-     *  @param reservation The enclosing reservation object of this place.
-     *  This matters to decide how to interpret the name/address/etc of the place.
      */
-    Q_INVOKABLE static KPublicTransport::Location locationFromPlace(const QVariant &place, const QVariant &reservation);
+    Q_INVOKABLE static KPublicTransport::Location locationFromPlace(const QVariant &place);
 
     /** Create a KItinerary place type from the given KPublicTransport::Location. */
     template<typename T>
@@ -69,12 +67,9 @@ public:
      */
     static QVariant applyJourneySection(const QVariant &res, const KPublicTransport::JourneySection &section);
 
-    /** Update a reservation from a KPublicTransport::Stopover.
-     *  This assumes the stopover matches the departure/arrival of the reservation, and in case
-     *  of conflict, the reservation is preferred.
+    /** Update a reservation from a KPublicTransport::JounreySection.
+     *  This does not verify both parts actually refer to the same journey.
      */
-    static QVariant mergeDeparture(const QVariant &res, const KPublicTransport::Stopover &dep);
-    static QVariant mergeArrival(const QVariant &res, const KPublicTransport::Stopover &arr);
     static QVariant mergeJourney(const QVariant &res, const KPublicTransport::JourneySection &journey);
 
     /** Checks whether @p mode is a bus or ship mode respectively. */
