@@ -93,7 +93,7 @@ QVariant TripGroupModel::data(const QModelIndex &index, int role) const
         return tripGroup.endDateTime();
     case PositionRole:
         // NOTE: when adjusting this adjust scheduleUpdate accordingly!
-        if (tripGroup.endDateTime().isValid() && today() > tripGroup.endDateTime().date()) {
+        if (tripGroup.hasEnded(now())) {
             return Position::Past;
         }
 
@@ -101,9 +101,6 @@ QVariant TripGroupModel::data(const QModelIndex &index, int role) const
             return Position::Future;
         }
 
-        if (!tripGroup.endDateTime().isValid() && tripGroup.beginDateTime().date() < today()) {
-            return Position::Past; // end-less are never current, the future case is already covered above
-        }
         return Position::Current;
     case TripGroupRole:
         return QVariant::fromValue(tripGroup);
@@ -543,6 +540,24 @@ QVariant TripGroupModel::locationAtTime(const QDateTime &dt) const
     return {};
 }
 
+int TripGroupModel::currentOrNextRow() const
+{
+    if (m_tripGroups.empty()) {
+        return -1;
+    }
+
+    const auto dt = now();
+    int row = 0;
+    for (; row < (int)m_tripGroups.size(); ++row) {
+        if (m_tripGroupManager->tripGroup(m_tripGroups[row]).hasEnded(dt)) {
+            --row;
+            break;
+        }
+    }
+
+    return std::clamp(row, 0, (int)m_tripGroups.size() - 1);
+}
+
 QDateTime TripGroupModel::now() const
 {
     if (Q_UNLIKELY(m_unitTestTime.isValid())) {
